==> haskell-shakespeare-2.0.25-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-shakespeare.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 shakespeare
version:              2.0.25
visibility:           public
id:                   shakespeare-2.0.25-NS3cV2vxtL2iJwu3F2ZQZ
key:                  shakespeare-2.0.25-NS3cV2vxtL2iJwu3F2ZQZ
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/shakespearean-templates
synopsis:             A toolkit for making compile-time interpolated templates
description:
    Shakespeare is a family of type-safe, efficient template languages. Shakespeare templates are expanded at compile-time, ensuring that all interpolated variables are in scope. Variables are interpolated according to their type through a typeclass.

    Shakespeare templates can be used inline with a quasi-quoter or in an external file.

    Note there is no dependency on haskell-src-extras. Instead Shakespeare believes logic should stay out of templates and has its own minimal Haskell parser.

    Packages that use this: xml-hamlet

    Please see the documentation at <http://www.yesodweb.com/book/shakespearean-templates> for more details.

category:             Web, Yesod
abi:                  3c12fbe90392284805dfc2d615c4810d
exposed:              True
exposed-modules:
    Text.Cassius Text.Coffee Text.Hamlet Text.Hamlet.RT
    Text.Hamlet.Runtime Text.Internal.Css Text.Internal.CssCommon
    Text.Julius Text.Lucius Text.Roy Text.Shakespeare
    Text.Shakespeare.Base Text.Shakespeare.I18N Text.Shakespeare.Text
    Text.TypeScript

hidden-modules:       Text.Hamlet.Parse Text.MkSizeType Text.IndentToBrace
import-dirs:          /usr/lib/ghc-8.10.2/site-local/shakespeare-2.0.25
library-dirs:         /usr/lib/ghc-8.10.2/site-local/shakespeare-2.0.25
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/shakespeare-2.0.25
hs-libraries:         HSshakespeare-2.0.25-NS3cV2vxtL2iJwu3F2ZQZ
depends:
    aeson-1.5.4.0-5vxqgGZiwHzJS2LSOWy84c base-4.14.1.0
    blaze-html-0.9.1.2-ANiJTYDDlVb8WcffrC5gl0
    blaze-markup-0.8.2.7-LxYHHNtMMqd23FQvjJOkWQ bytestring-0.10.10.0
    containers-0.6.2.1 directory-1.3.6.0 exceptions-0.10.4
    ghc-prim-0.6.1 parsec-3.1.14.0 process-1.6.9.0
    scientific-0.3.6.2-A8GBaVrldouFqR9nCedoU6 template-haskell-2.16.0.0
    text-1.2.3.2 th-lift-0.8.2-AJkuFkuzyRi6AKRTsQMqMN time-1.9.3
    transformers-0.5.6.2
    unordered-containers-0.2.12.0-5Ef7XCamkg9H83KRAEej2p
    vector-0.12.1.2-KHX5U3TBRrFFuOQ5e4wn9L

haddock-interfaces:   /usr/share/doc/haskell-shakespeare/html/shakespeare.haddock
haddock-html:         /usr/share/doc/haskell-shakespeare/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-shakespeare-2.0.25-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-shakespeare.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 shakespeare
version:              2.0.25
visibility:           public
id:                   shakespeare-2.0.25-CBUIVt4JGEbKOR1kvGfr0q
key:                  shakespeare-2.0.25-CBUIVt4JGEbKOR1kvGfr0q
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/shakespearean-templates
synopsis:             A toolkit for making compile-time interpolated templates
description:
    Shakespeare is a family of type-safe, efficient template languages. Shakespeare templates are expanded at compile-time, ensuring that all interpolated variables are in scope. Variables are interpolated according to their type through a typeclass.

    Shakespeare templates can be used inline with a quasi-quoter or in an external file.

    Note there is no dependency on haskell-src-extras. Instead Shakespeare believes logic should stay out of templates and has its own minimal Haskell parser.

    Packages that use this: xml-hamlet

    Please see the documentation at <http://www.yesodweb.com/book/shakespearean-templates> for more details.

category:             Web, Yesod
abi:                  9a423103b86c405c16e46cf1b6e1ba6b
exposed:              True
exposed-modules:
    Text.Cassius Text.Coffee Text.Hamlet Text.Hamlet.RT
    Text.Hamlet.Runtime Text.Internal.Css Text.Internal.CssCommon
    Text.Julius Text.Lucius Text.Roy Text.Shakespeare
    Text.Shakespeare.Base Text.Shakespeare.I18N Text.Shakespeare.Text
    Text.TypeScript

hidden-modules:       Text.Hamlet.Parse Text.MkSizeType Text.IndentToBrace
import-dirs:          /usr/lib/ghc-8.10.2/site-local/shakespeare-2.0.25
library-dirs:         /usr/lib/ghc-8.10.2/site-local/shakespeare-2.0.25
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/shakespeare-2.0.25
hs-libraries:         HSshakespeare-2.0.25-CBUIVt4JGEbKOR1kvGfr0q
depends:
    aeson-1.5.4.1-2YgQvnoUGUbFY9GKPCy4dR base-4.14.1.0
    blaze-html-0.9.1.2-9k65hKYSD012WlLjR56Fls
    blaze-markup-0.8.2.7-LxYHHNtMMqd23FQvjJOkWQ bytestring-0.10.10.0
    containers-0.6.2.1 directory-1.3.6.0 exceptions-0.10.4
    ghc-prim-0.6.1 parsec-3.1.14.0 process-1.6.9.0
    scientific-0.3.6.2-3Rl1TFr6D8iHoas19Ro04G template-haskell-2.16.0.0
    text-1.2.3.2 th-lift-0.8.2-AJkuFkuzyRi6AKRTsQMqMN time-1.9.3
    transformers-0.5.6.2
    unordered-containers-0.2.13.0-1ou2s75HM4jIGJQqER9UBk
    vector-0.12.1.2-93zBJ8pozDnK4B1K8k25VC

haddock-interfaces:   /usr/share/doc/haskell-shakespeare/html/shakespeare.haddock
haddock-html:         /usr/share/doc/haskell-shakespeare/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
